elephant.spike\_train\_generation.threshold\_detection
======================================================

.. currentmodule:: elephant.spike_train_generation

.. autofunction:: threshold_detection